@@ -15,7 +15,6 @@
 
 #include "application.h"
 #include "version.h"
-#include "commit.h"
 
 #include <QMutex>
 #include <QWaitCondition>
@@ -26,11 +25,9 @@
 #include <Kdelibs4ConfigMigrator>
 #include <KDBusAddons/KDBusService>
 
-#define HACKSTR(x) #x
-#define STRHACK(x) HACKSTR(x)
-
 int main(int argc, char* argv[])
 {
+    Application app(argc, argv);
 
     // Migrate pre-existing (4.x) configuration
 
@@ -44,16 +41,14 @@ int main(int argc, char* argv[])
     migrate.setUiFiles(QStringList() << QLatin1String("konversationui.rc"));
     migrate.migrate();
 
-    Application app(argc, argv);
-
     KLocalizedString::setApplicationDomain("konversation");
 
     KAboutData aboutData("konversation",
         i18n("Konversation"),
-        KONVI_VERSION " #" STRHACK(COMMIT),
+        KONVI_VERSION,
         i18n("A user-friendly IRC client"),
         KAboutLicense::GPL,
-        i18n("(C) 2002-2016 by the Konversation team"),
+        i18n("(C) 2002-2017 by the Konversation team"),
         i18n("Konversation is a client for the Internet Relay Chat (IRC) protocol.\n\n"
         "Meet friends on the net, make new acquaintances and lose yourself in talk about your favorite subject."),
         QStringLiteral("http://konversation.kde.org/"));
@@ -106,8 +101,8 @@ int main(int argc, char* argv[])
     app.setOrganizationDomain(aboutData.organizationDomain());
     app.setApplicationVersion(aboutData.version());
     app.setApplicationDisplayName(aboutData.displayName());
+    app.setWindowIcon(QIcon::fromTheme(QLatin1String("konversation"), app.windowIcon()));
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    app.setWindowIcon(QIcon::fromTheme(QLatin1String("konversation")));
 
     QCommandLineParser cmdLineParser;
     cmdLineParser.addHelpOption();
@@ -121,8 +116,8 @@ int main(int argc, char* argv[])
     cmdLineParser.addOption(QCommandLineOption(QStringLiteral("password"), i18n("Password for connection"), i18n("password")));
     cmdLineParser.addOption(QCommandLineOption(QStringLiteral("ssl"), i18n("Use SSL for connection")));
     cmdLineParser.addOption(QCommandLineOption(QStringLiteral("noautoconnect"), i18n("Disable auto-connecting to any IRC networks")));
-    cmdLineParser.addOption(QCommandLineOption(QStringLiteral("startupdelay"), i18n("Delay D-Bus activity and UI creation by the specified amount of miliseconds"), i18n("msec"), "2000"));
-    // cmdLineParser.addOption(QCommandLineOption(QStringLiteral("restart"), i18n("Quits and restarts Konversation (if running, otherwise has no effect)"))); FIXME KF5 Port: --restart
+    cmdLineParser.addOption(QCommandLineOption(QStringLiteral("startupdelay"), i18n("Delay D-Bus activity and UI creation by the specified amount of milliseconds"), i18n("msec"), "2000"));
+    cmdLineParser.addOption(QCommandLineOption(QStringLiteral("restart"), i18n("Quits and restarts Konversation (if running, otherwise has no effect)")));
 #ifndef QT_NO_DEBUG
     cmdLineParser.addOption(QCommandLineOption(QStringLiteral("nui"), i18n("Sets KUniqueApplication::NonUniqueInstance (debug only, use with caution)")));
 #endif
@@ -151,14 +146,17 @@ int main(int argc, char* argv[])
         startOptions = KDBusService::Multiple;
 #endif
 
+    startOptions |= KDBusService::NoExitOnFailure;
+
     KDBusService dbusService(startOptions);
 
     aboutData.processCommandLine(&cmdLineParser);
     app.newInstance(&cmdLineParser);
+    app.setCommandLineParser(&cmdLineParser);
 
     QObject::connect(&dbusService, &KDBusService::activateRequested,
-        app.instance()->getMainWindow(), &MainWindow::activateAndRaiseWindow,
-        Qt::DirectConnection);
+                     &app, &Application::handleActivate,
+                     Qt::DirectConnection);
 
     return app.exec();
 }
